@@ -24,7 +24,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.7.4';
+our $VERSION = '3.7.5';
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ my %valid_options = (
     key           => {valid => [qr/^.{15}/], default => undef},
     client_id     => {valid => [qr/^.{15}/], default => undef},
     client_secret => {valid => [qr/^.{15}/], default => undef},
-    redirect_uri  => {valid => [qr/^.{15}/], default => undef},
+    redirect_uri  => {valid => [qr/^.{15}/], default => 'urn:ietf:wg:oauth:2.0:oob'},
     access_token  => {valid => [qr/^.{15}/], default => undef},
     refresh_token => {valid => [qr/^.{15}/], default => undef},
 
@@ -777,7 +777,7 @@ sub _extract_streaming_urls {
     @results = grep { not exists $_->{cipher} } @results;
 
     # Keep only streams with contentLength > 0.
-    @results = grep { exists($_->{contentLength}) and $_->{contentLength} > 0 } @results;
+    @results = grep { $_->{itag} == 22 or (exists($_->{contentLength}) and $_->{contentLength} > 0) } @results;
 
     # Detect livestream
     if (!@results and exists($json->{streamingData}) and exists($json->{streamingData}{hlsManifestUrl})) {
